14.Operations and maintenance
1. Create traffic query task
API address: /v1/instance/flow/query
Request method:POST
Request data type:application/json
Response data type:*/*,application/json
Supported version:v1.18.0
API description:
Create traffic query task, throughGet traffic query task resultAPI query result
Request parameters:
| Parameter name | Parameter description | Location | Whether required | Data type | Description |
|---|---|---|---|---|---|
| instanceUuids | Container uuid | body | true | list | Single or multiple container data entries |
| startTime | Start time | body | true | string | Query start time (must be on the hour), format yyyy-MM-dd hh:mm:ss |
| endTime | End time | body | true | string | Query end time (must be on the hour), format yyyy-MM-dd hh:mm:ss |
| billingType | Billing type | body | true | string | Enum type: PEEKPERCENT95 (95th percentile peak bandwidth billing) |
| taskDesc | Task description | body | false | string | Task description |
Request example. Replace parameter values in the actual request:
POST "/openapi/v1/instance/flow/query"
body:
{
"instanceUuids": ["i-236a0f378e9f109584d13c3591c42dff","i-39757fe1833c29fd0ef8263b8d2f46d3"],
"startTime":"2023-09-01 18:00:00",
"endTime":"2023-10-01 18:00:00",
"billingType":"PEEKPERCENT95",
"taskDesc":"2023年9月份流量汇总"
}
Response parameters:
| Parameter name | Parameter description | Type | Description |
|---|---|---|---|
| code | Return code | integer | |
| message | Return processing message | string | |
| result | Returned data object | list<object> | |
| jobId | Task ID | string | |
| timestamp | Timestamp | integer | |
| traceId | Request processing ID | string |
Response example:
{
"message": "操作成功!",
"code": 200,
"result": {
"jobId": "4730ee885e6845ec8a4f026fe90e7920"
},
"timestamp": 1705479262853,
"traceId": "C20240117161421507001"
}
2. Get traffic query task result
API address: /v1/instance/flow/query/result/{jobId}
Request method:POST
Request data type:application/json
Response data type:*/*,application/json
Supported version:v1.18.0
API description:
Get traffic query task result
Request parameters:
| Parameter name | Parameter description | Location | Whether required | Data type | Description |
|---|---|---|---|---|---|
| jobId | jobId returned after calling the interface | path | true | string | Task ID |
Request example. Replace parameter values in the actual request:
Response parameters:
| Parameter name | Parameter description | Type | Description |
|---|---|---|---|
| code | Return code | integer | |
| message | Return processing message | string | |
| result | Returned data object | list<object> | |
| jobId | Task ID | string | |
| status | Task execution status | int | 1:executing 2:execution succeeded -1:execution failed |
| billingType | Billing type | string | Enum type: PEEKPERCENT95 (95th percentile peak bandwidth billing) |
| billingValue | Billing value | double | Has a value in successful status, bandwidth (unit: bps) |
| bandwidthList | Bandwidth details list | list<object> | |
| recordTime | Record time | long | |
| receive | Receive data | double | Unit: bps |
| send | Send data | double | Unit: bps |
| timestamp | Timestamp | integer | |
| traceId | Request processing ID | string |
Response example:
{
"message": "操作成功!",
"code": 200,
"result": {
"jobId": "4730ee885e6845ec8a4f026fe90e7920",
"taskDesc":"2023年9月份流量汇总",
"status":2,
"billingType":"PEEKPERCENT95",
"billingValue":100.0,
"bandwidthList":[{
"recordTime":1676020200000,
"receive":50.0,
"send":50.0
}]
},
"timestamp": 1705479262853,
"traceId": "C20240117161421507001"
}
3. Query server online status
API address: /v1/arm/server/query/online/status
Request method:POST
Request data type:application/json
Response data type:*/*,application/json
Supported version:v1.19.0
API description:
Query server online status
Request parameters:
| Parameter name | Parameter description | Location | Whether required | Data type | Description |
|---|---|---|---|---|---|
| nodeUuid | Node uuid | body | true | string | |
| armServerUuids | Server uuid list | body | true | list |
Request example. Replace parameter values in the actual request:
POST "/openapi/v1/arm/server/query/online/status"
body:
{
"armServerUuids":["s-08f5fb859a9d9161c2727bf57e586f02"],
"nodeUuid":"81f62329436eed8f36d0595bf81b63db"
}
Response parameters:
| Parameter name | Parameter description | Type | Description |
|---|---|---|---|
| code | Return code | integer | |
| message | Return processing message | string | |
| result | Returned data object | object | |
| serverList | Key-value pair | object | key is uuid, value is status (1:online; 0:offline) |
| timestamp | Timestamp | integer | |
| traceId | Request processing ID | string |
Response example:
{
"message": "操作成功",
"code": 200,
"result": {
"serverList": {
"s-08f5fb859a9d9161c2727bf57e586f02": 1
}
},
"timestamp": 1736495691785,
"traceId": "E20250110155451785129"
}
4. Query board card online status
API address: /v1/arm/card/query/online/status
Request method:POST
Request data type:application/json
Response data type:*/*,application/json
Supported version:v1.19.0
API description:
Query card online status
Request parameters:
| Parameter name | Parameter description | Location | Whether required | Data type | Description |
|---|---|---|---|---|---|
| nodeUuid | Node uuid | body | true | string | |
| uuids | Card uuid list | body | true | list |
Request example. Replace parameter values in the actual request:
POST "/v1/arm/card/query/online/status"
body:
{
"uuids":["26d9132fdfe8fe58e52ea13033239ac3","8398e402e6bd85c7e27f15f088d8d9e2"],
"nodeUuid":"81f62329436eed8f36d0595bf81b63db"
}
Response parameters:
| Parameter name | Parameter description | Type | Description |
|---|---|---|---|
| code | Return code | integer | |
| message | Return processing message | string | |
| result | Returned data object | object | |
| armCardList | Key-value pair | object | key is uuid, value is status (1:online; 0:offline) |
| timestamp | Timestamp | integer | |
| traceId | Request processing ID | string |
Response example:
{
"message": "操作成功",
"code": 200,
"result": {
"armCardList": {
"8398e402e6bd85c7e27f15f088d8d9e2": 1,
"26d9132fdfe8fe58e52ea13033239ac3": 1
}
},
"timestamp": 1736496285388,
"traceId": "E20250110160445388133"
}
5. Query board card resource usage
API address: /v1/system/resource/current
Request method:POST
Request data type:application/json
Response data type:*/*,application/json
Supported version:v1.19.0
API description:
Query card cpu, memory, and disk resource usage
Request parameters:
| Parameter name | Parameter description | Location | Whether required | Data type | Description |
|---|---|---|---|---|---|
| snList | Card sn list | body | true | list | If the value of uuids is passed, snList is not passed; only one of the two parameters is passed |
| uuids | Card uuid list | body | true | list | If the value of snList is passed, uuids is not passed; only one of the two parameters is passed |
| type | Type | body | true | integer | 1:board card. Currently only the board card type is supported |
Request example. Replace parameter values in the actual request:
Response parameters:
| Parameter name | Parameter description | Type | Description |
|---|---|---|---|
| code | Return code | integer | |
| message | Return processing message | string | |
| result | Returned data object | object | |
| list | Data object | object | |
| sn or uuid | sn or uuid | string | |
| recordTime | Timestamp (seconds) | long | Collected time point |
| cpuCore | total cpu cores | string | |
| cpuUsageActive | cpu usage rate | string | |
| memTotal | Total memory | string | |
| memAvailable | Available memory | string | |
| memActualUsed | Actual memory used | string | |
| memUsedPercent | Memory usage rate | string | |
| diskTotal | Total disk | string | |
| diskUsed | Disk usage amount | string | |
| diskUsedPercent | Disk usage rate | string | |
| timestamp | Timestamp | integer | |
| traceId | Request processing ID | string |
Response example:
{
"code": 200,
"result": {
"list": {
"OR65Q61QC2D240402603": {
"cpuCore": "8",
"cpuUsageActive": "3.52%",
"diskTotal": "223.59G",
"diskUsed": "11.60G",
"diskUsedPercent": "5.19%",
"memActualUsed": "2.58G",
"memAvailable": "8.89G",
"memTotal": "11.47G",
"memUsedPercent": "22.49%",
"recordTime": 1755225150
},
"OR65Q61QC2D240403791": {
"cpuCore": "8",
"cpuUsageActive": "3.59%",
"diskTotal": "223.59G",
"diskUsed": "10.95G",
"diskUsedPercent": "4.90%",
"memActualUsed": "2.58G",
"memAvailable": "8.88G",
"memTotal": "11.47G",
"memUsedPercent": "22.52%",
"recordTime": 1755225150
}
}
},
"success": true,
"timestamp": 0
}
6. Recycle board card (formerly unsubscribe board card)
API address: /v1/arm/card/apply/release
Request method: POST
Request data type: application/json
Response data type: */*,application/json
Supported version: v1.18.0
callbackUrl provided by version v1.19.0
API description:
Recycle board card (formerly unsubscribe board card; planned later as an admin-only API, permission control will be added)
Request parameters:
| Parameter name | Parameter description | Location | Whether required | Data type | Description |
|---|---|---|---|---|---|
| nodeUuid | Node uuid | body | true | string | |
| batchMap | Card uuid/card name key-value pair | body | false | object | This field is planned to be taken offline later. It is recommended to pass the value of the uuids field instead of this field |
| uuids | Card uuid list | body | true | List<String> | Replace batchMap |
| deepRelease | Deep recycle | body | false | boolean | There is a recycling task after releasing the board. When the value is true, the recycle task process: destroy board card containers->Automatic qfile flashing->Rebind board ip->Install the latest cce, ccem; When the value is false, the recycle task process: destroy board card containers |
| callbackUrl | Notification callback address | body | false | string | POST request |
Request example
POST "/openapi/v1/arm/card/apply/release"
body:
{
"batchMap":{
"e123de61c90d0abbd503c48c769bb38a":"fjz-api-1"
},
"uuids": ["e123de61c90d0abbd503c48c769bb38a"],
"nodeUuid":"81f62329436eed8f36d0595bf81b63db",
"deepRelease": true,
"callbackUrl": "http://127.0.0.1/notice"
}
Response parameters:
| Parameter name | Parameter description | Type | Description |
|---|---|---|---|
| code | Return code | integer(int32) | |
| message | Return processing message | string | |
| result | Returned data object | object | |
| recycleJobs | Recycle task result | list<object> | |
| jobId | Task id | string | Card reclaim task id, this jobId is used to query task details |
| code | Task submission status code | integer | CorrespondingResponse status code table |
| message | Task submission description | string | |
| uuid | Card uuid | string | |
| sn | Card SN | string | |
| recycleTraceId | Recycle task business ID | string | |
| jobs | Task result | list<object> | |
| jobId | Task id | string | |
| code | Task submission status code | integer | CorrespondingResponse status code table |
| message | Task submission description | string | |
| uuid | Card uuid | string | |
| sn | Card SN | string | |
| timestamp | Timestamp | integer(int64) | |
| traceId | Request processing ID | string |
Response example:
{
"message": "操作成功",
"code": 200,
"result": {
"recycleJobs": [
{
"jobId": "4431f0758c244106950b1a98f358d433",
"code": 200,
"sn": "OR65Q61QC2D240403252",
"recycleTraceId": "E20250326183529385229_1",
"message": "success",
"uuid": "ef8f33d103ffc9b79af8709397e3d559"
}
],
"jobs": [
{
"jobId": "c5ebec444805454c97f8884804796dde",
"code": 200,
"sn": "OR65Q61QC2D240403252",
"message": "success",
"uuid": "ef8f33d103ffc9b79af8709397e3d559"
}
]
},
"timestamp": 1742985329522,
"traceId": "E20250326183529385229"
}